{% load i18n %}
<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
    <title>{{ subject }}</title>
    {% block styles %}
      <style>{% include "emark/styles.css" %}</style>
    {% endblock styles %}
  </head>
  <body>
    {% block preheader %}
      {% spaceless %}
        <span class="preheader"></span>
      {% endspaceless %}
    {% endblock preheader %}
    <table role="presentation"
           border="0"
           cellpadding="0"
           cellspacing="0"
           class="body">
      <tr>
        <td class="container-padding">&#xfeff;</td>
        <td class="container">
          <div class="content">
            <!-- START CENTERED WHITE CONTAINER -->
            {% block container %}
              <table role="presentation" class="main">
                <!-- START MAIN CONTENT AREA -->
                {% block main %}
                  <tr>
                    <td class="wrapper">
                      <table role="presentation" border="0" cellpadding="0" cellspacing="0">
                        <tr>
                          <td>
                            <!-- START ACTUAL CONTENT -->
                            {% spaceless %}
                              {% block content %}{{ markdown_string }}{% endblock %}
                            {% endspaceless %}
                            <!-- END ACTUAL CONTENT -->
                          </td>
                        </tr>
                      </table>
                    </td>
                  </tr>
                {% endblock main %}
                <!-- END MAIN CONTENT AREA -->
              </table>
            {% endblock container %}
            <!-- END CENTERED WHITE CONTAINER -->
            <!-- START FOOTER -->
            <div class="footer">
              <table role="presentation" border="0" cellpadding="0" cellspacing="0">
                <tr>
                  <td class="content-block">
                    {% spaceless %}
                      {% block footer %}{% endblock %}
                    {% endspaceless %}
                  </td>
                </tr>
              </table>
            </div>
            <!-- END FOOTER -->
          </div>
        </td>
        <td class="container-padding">&#xfeff;</td>
      </tr>
    </table>
  </body>
</html>
